@@ -32,9 +32,9 @@ USER_RESOURCE = 'user/register'
 USER_CREATE_URL = '{}/{}?clientId={}&clientSecret={}&username={}&password={}&date={}'
 
 TOKEN_RESOURCE = 'oauth2/token'
-TOKEN_CREATE_URL = 'https://api.ttlock.com/{}?client_id={}&client_secret={}&username={}&password={}&grant_type=password&redirect_uri={}'
+TOKEN_CREATE_URL = 'https://euapi.ttlock.com/{}?client_id={}&client_secret={}&username={}&password={}&grant_type=password&redirect_uri={}'
 
-TOKEN_REFRESH_URL = 'https://api.ttlock.com/{}?client_id={}&client_secret={}&refresh_token={}&grant_type=refresh_token&redirect_uri={}'
+TOKEN_REFRESH_URL = 'https://euapi.ttlock.com/{}?client_id={}&client_secret={}&refresh_token={}&grant_type=refresh_token&redirect_uri={}'
 
 
 UNLOCK_CODES = {1:'App unlock', 2:'touch the parking lock', 3:'gateway unlock', 4:'passcode unlock', 5:'parking lock raise', 6:'parking lock lower', 7:'IC card unlock', 8:'fingerprint unlock', 9:'wristband unlock', 10:'mechanical key unlock', 11:'Bluetooth lock', 12:'gateway unlock', 29:'unexpected unlock', 30:'door magnet close', 31:'door magnet open', 32:'open from inside', 33:'lock by fingerprint', 34:'lock by passcode', 35:'lock by IC card', 36:'lock by Mechanical key', 37:'Remote Control', 44:'Tamper alert', 45:'Auto Lock', 46:'unlock by unlock key', 47:'lock by lock key', 48:'Use INVALID Passcode several times'}
\ No newline at end of file
